@@ -14,6 +14,8 @@
 #      Markdown document to be compiled.}
 #   \item{...}{Additional arguments passed to @see "markdown::markdownToHTML".}
 #   \item{outPath}{The output and working directory.}
+#   \item{header}{@character @vector of valid HTML strings that should be added to the HTML <head> section.}
+#   \item{metadata}{A named @list with meta data that will add as <meta> tags in the HTML <head> section.}
 #   \item{verbose}{See @see "R.utils::Verbose".}
 # }
 #
@@ -31,7 +33,7 @@
 # @keyword IO
 # @keyword internal
 #*/###########################################################################
-setMethodS3("compileMarkdown", "default", function(filename, path=NULL, ..., outPath=".", verbose=FALSE) {
+setMethodS3("compileMarkdown", "default", function(filename, path=NULL, ..., outPath=".", header=NULL, metadata=getMetadata(filename), verbose=FALSE) {
   # Load the package (super quietly), in case R.rsp::nnn() was called.
   use("markdown", quietly=TRUE);
 
@@ -48,6 +50,10 @@ setMethodS3("compileMarkdown", "default", function(filename, path=NULL, ..., out
   outPath <- Arguments$getWritablePath(outPath);
   if (is.null(outPath)) outPath <- ".";
 
+  # Argument 'metadata':
+  if (is.null(metadata)) metadata <- list()
+  stopifnot(is.list(metadata))
+
   # Argument 'verbose':
   verbose <- Arguments$getVerbose(verbose);
   if (verbose) {
@@ -55,8 +61,30 @@ setMethodS3("compileMarkdown", "default", function(filename, path=NULL, ..., out
     on.exit(popState(verbose));
   }
 
+  # Arguments '...':
+
 
   verbose && enter(verbose, "Compiling Markdown document");
+
+  ## Incorporate meta data into HTML header?
+  if (length(metadata) > 0L) {
+    keywords <- metadata[["keywords"]]
+    if (length(keywords) > 0L) {
+      keywords <- paste(keywords, collapse=", ")
+      headerT <- sprintf('<meta name="keywords" content="%s">', keywords)
+      header <- c(header, headerT)
+    }
+
+    author <- metadata[["author"]]
+    if (length(author) > 0L) {
+      author <- paste(author, collapse=", ")
+      headerT <- sprintf('<meta name="author" content="%s">', author)
+      header <- c(header, headerT)
+    }
+  }
+  header <- paste(header, collapse="\n")
+
+
   # Download URL?
   if (isUrl(pathname)) {
     verbose && enter(verbose, "Downloading URL");
@@ -95,13 +123,13 @@ setMethodS3("compileMarkdown", "default", function(filename, path=NULL, ..., out
 
   # Workaround for bug in markdown v0.5.4. /HB 2013-03-28
   if (packageVersion("markdown") <= "0.5.4") {
-    args <- c(list(pathnameR, output=NULL), userArgs);
+    args <- c(list(pathnameR, output=NULL), userArgs, header=header);
     verbose && cat(verbose, "Arguments to markdownToHTML():");
     verbose && str(verbose, args);
     bfr <- do.call(mdToHTML, args=args);
     cat(bfr, file=pathnameOutR);
   } else {
-    args <- c(list(pathnameR, output=pathnameOutR), userArgs);
+    args <- c(list(pathnameR, output=pathnameOutR), userArgs, header=header);
     verbose && cat(verbose, "Arguments to markdownToHTML():");
     verbose && str(verbose, args);
     do.call(mdToHTML, args=args);
@@ -120,8 +148,11 @@ setMethodS3("compileMarkdown", "default", function(filename, path=NULL, ..., out
 }) # compileMarkdown()
 
 
+
 ############################################################################
 # HISTORY:
+# 2015-02-04
+# o Added arguments 'header' and 'metadata' to compileMarkdown().
 # 2013-03-28
 # o PATCH: compileMarkdown() works around bug in markdown v0.5.4.
 #   I have reported the bug to the 'markdown' maintainer.
